package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.ActionConfig;

/**
 * 动作配置管理Mapper接口
 * 
 * @author hmy
 * @date 2025-04-28
 */
public interface ActionConfigMapper extends BaseMapper<ActionConfig>
{
    /**
     * 查询动作配置管理
     * 
     * @param actionId 动作配置管理主键
     * @return 动作配置管理
     */
    public ActionConfig selectActionConfigByActionId(Long actionId);

    /**
     * 查询动作配置管理列表
     * 
     * @param actionConfig 动作配置管理
     * @return 动作配置管理集合
     */
    public List<ActionConfig> selectActionConfigList(ActionConfig actionConfig);

    /**
     * 新增动作配置管理
     * 
     * @param actionConfig 动作配置管理
     * @return 结果
     */
    public int insertActionConfig(ActionConfig actionConfig);

    /**
     * 修改动作配置管理
     * 
     * @param actionConfig 动作配置管理
     * @return 结果
     */
    public int updateActionConfig(ActionConfig actionConfig);

    /**
     * 删除动作配置管理
     * 
     * @param actionId 动作配置管理主键
     * @return 结果
     */
    public int deleteActionConfigByActionId(Long actionId);

    /**
     * 批量删除动作配置管理
     * 
     * @param actionIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteActionConfigByActionIds(Long[] actionIds);
}
